@@ -29,10 +29,14 @@ __all__ = [
     "s_disk_structure",
     "s_disk_details",
     "s_disk_format_progress",
+    "start_dhcp_server_command",
+    "stop_dhcp_server_command",
+    "extended_response_generic",
     "s_ext_sub_cmd_hdr",
     "s_ext_sub_cmd_comm",
     "serdescam_settings",
     "serdespoc_settings",
+    "serdesgen_settings",
     "rad_moon_duo_converter_settings",
     "rad_reporting_settings",
     "s_fire_settings",
@@ -48,6 +52,7 @@ __all__ = [
     "srad_galaxy_settings",
     "srad_star2_settings",
     "srad_super_moon_settings",
+    "srada2_b_settings",
     "srad_moon2_settings",
     "srad_gigalog_settings",
     "srad_gigastar_settings",
@@ -114,7 +119,10 @@ __all__ = [
     "op_eth_link_mode",
     "e_disk_format",
     "e_disk_layout",
+    "extended_response_code",
     "flex_vnet_mode",
     "e_device_settings_type",
     "e_plasma_ion_vnet_channel_t",
+    "s_phy_reg_pkt_status",
+    "s_phy_reg_pkt_rw",
 ]
