@@ -2,9 +2,9 @@
 #define _DEFINES_H_
 #include <Python.h>
 
-#define MODULE_NAME "ics"
+#define MODULE_NAME "ics.ics"
 #define MODULE_DESCRIPTION "Copyright Intrepid Control Systems, Inc."
-#define VSPY3_BUILD_VERSION 900
+#define VSPY3_BUILD_VERSION 901
 
 
 // https://bugs.python.org/issue28769
@@ -21,11 +21,6 @@
 #error Failed to suppport PyUnicode_AsUTF8
 #endif
 
-// Enable use of generic device settings object in 803 or newer.
-#if !defined(USE_GENERIC_DEVICE_SETTINGS) && (VSPY3_BUILD_VERSION >= 803)
-#define USE_GENERIC_DEVICE_SETTINGS
-#endif
-
 #ifdef _cplusplus
 extern "C" {
 #endif
