@@ -1,15 +1,9 @@
 #ifndef _METHODS_H_
 #define _METHODS_H_
 #include <Python.h>
-#include "object_vcan3_settings.h"
-#include "object_fire_settings.h"
 #include "object_neo_device.h"
-#include "object_api_firmware_info.h"
+#include "object_spy_message.h"
 #include "setup_module_auto_defines.h"
-#include "object_cm_iso157652_tx_message.h"
-#include "object_cm_iso157652_rx_message.h"
-#include "object_ics_device_status.h"
-#include "object_device_settings.h"
 
 #ifdef _cplusplus
 extern "C" {
@@ -63,7 +57,7 @@ PyObject* meth_firmware_update_required(PyObject* self, PyObject* args);
 PyObject* meth_get_dll_firmware_info(PyObject* self, PyObject* args);
 PyObject* meth_get_backup_power_enabled(PyObject* self, PyObject* args);
 PyObject* meth_set_backup_power_enabled(PyObject* self, PyObject* args);
-PyObject* meth_set_backup_power_ready(PyObject* self, PyObject* args);
+PyObject* meth_get_backup_power_ready(PyObject* self, PyObject* args);
 PyObject* meth_load_readbin(PyObject* self, PyObject* args);
 PyObject* meth_iso15765_transmit_message(PyObject* self, PyObject* args); // icsneoISO15765_TransmitMessage
 PyObject* meth_iso15765_receive_message(PyObject* self, PyObject* args); // icsneoISO15765_ReceiveMessageMessage
@@ -81,6 +75,12 @@ PyObject* meth_get_device_status(PyObject* self, PyObject* args);
 PyObject* meth_enable_network_com(PyObject* self, PyObject* args); //icsneoEnableNetworkCom
 PyObject* meth_enable_bus_voltage_monitor(PyObject* self, PyObject* args);
 PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
+PyObject* meth_read_jupiter_firmware(PyObject* self, PyObject* args);
+PyObject* meth_write_jupiter_firmware(PyObject* self, PyObject* args);
+PyObject* meth_get_disk_details(PyObject* self, PyObject* args);
+PyObject* meth_disk_format(PyObject* self, PyObject* args);
+PyObject* meth_disk_format_cancel(PyObject* self, PyObject* args);
+PyObject* meth_get_disk_format_progress(PyObject* self, PyObject* args);
 
 #ifdef _cplusplus
 }
@@ -88,12 +88,12 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
 
 #define _EZ_ICS_STRUCT_METHOD(name, icsname, icsname_no_icsneo, meth, flags, doc) \
     {name, (PyCFunction)meth, flags, doc}, \
-    {icsname, (PyCFunction)meth, flags, "\n.. note:: Compatibility Function\n\tIdentical to PEP8 compliant :func:`" MODULE_NAME "." name "` method.\n\n"}, \
-    {icsname_no_icsneo, (PyCFunction)meth, flags, "\n.. note:: Compatibility Function\n\tIdentical to PEP8 compliant :func:`" MODULE_NAME "." name "` method.\n\n"}
+    {icsname, (PyCFunction)meth, flags, "\n.. note:: Compatibility Function: Identical to PEP8 compliant :func:`" MODULE_NAME "." name "` method.\n\n"}, \
+    {icsname_no_icsneo, (PyCFunction)meth, flags, "\n.. note:: Compatibility Function: Identical to PEP8 compliant :func:`" MODULE_NAME "." name "` method.\n\n"}
 
 #define _EZ_ICS_STRUCT_METHOD_MULTIPLE(name, icsname, icsname_no_icsneo, meth, flags, doc) \
-    {icsname, (PyCFunction)meth, flags, "\n.. note:: Compatibility Function\n\tIdentical to PEP8 compliant :func:`" MODULE_NAME "." name "` method.\n\n"}, \
-    {icsname_no_icsneo, (PyCFunction)meth, flags, "\n.. note:: Compatibility Function\n\tIdentical to PEP8 compliant :func:`" MODULE_NAME "." name "` method.\n\n"}
+    {icsname, (PyCFunction)meth, flags, "\n.. note:: Compatibility Function: Identical to PEP8 compliant :func:`" MODULE_NAME "." name "` method.\n\n"}, \
+    {icsname_no_icsneo, (PyCFunction)meth, flags, "\n.. note:: Compatibility Function: Identical to PEP8 compliant :func:`" MODULE_NAME "." name "` method.\n\n"}
 
 #define _DOC_FIND_DEVICES \
     MODULE_NAME ".find_devices(device_type=" MODULE_NAME ".NEODEVICE_ALL)\n" \
@@ -103,8 +103,8 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "Args:\n" \
     "\tdevice_type (int): Accepts " MODULE_NAME ".NEODEVICE_* Macros\n\n" \
     "\t*New in 3.0 (803):*\n\n" \
-    "\tdevice_type (List/Tuple): Accepts a Container of " MODULE_NAME ".NEODEVICE_* Macros\n\n" \
-    "\tstOptionsOpenNeoEx (int): Usually ics.NETID_CAN, if needed\n\n" \
+    "\tdevice_types (List/Tuple): Accepts a Container of " MODULE_NAME ".NEODEVICE_* Macros\n\n" \
+    "\tnetwork_id (int): OptionsFindNeoEx.CANOptions.iNetworkID. Usually ics.NETID_CAN, if needed\n\n" \
     "\n" \
     "Raises:\n" \
     "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
@@ -132,10 +132,11 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "Args:\n" \
     "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
     "\tdevice (int): Serial Number of the device\n\n" \
-    "\tbNetworkIDs (int): Network Enables\n\n" \
-    "\tbConfigRead (int): Config Read\n\n" \
-    "\tiOptions (int): DEVICE_OPTION_* defines\n\n" \
-    "\tstOptionsOpenNeoEx (int): Usually ics.NETID_CAN, if needed\n\n" \
+    "\tnetwork_ids (List/Tuple): This is an array of number IDs which specify the NetworkID parameter of each network. This allows you to assign a custom network ID to each network. Normally, you will assign consecutive IDs to each of the networks. See NetworkIDList for a list of current network ID's. You may also set this parameter to NULL (zero) and the default network ID's will be used.\n\n" \
+    "\tbconfig_read (int): Specifies whether the DLL should read the neoVI's device configuration before enabling the device. It is recommended that this value be set to 1.\n\n" \
+    "\toptions (int): DEVICE_OPTION_* defines\n\n" \
+    "\tnetwork_id (int): OptionsFindNeoEx.CANOptions.iNetworkID. Usually ics.NETID_CAN, if needed\n\n" \
+    "\tuse_server (int): Defaults to False, Setting to True allows opening the same device more than once.\n\n" \
     "\n" \
     "Raises:\n" \
     "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
@@ -389,20 +390,21 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "\t>>> ics.set_reflash_callback(callback)\n" \
     "\t>>> \n" 
 
-#if defined(USE_GENERIC_DEVICE_SETTINGS)
 #define _DOC_GET_DEVICE_SETTINGS \
-    MODULE_NAME ".get_device_settings(device, vnet_slot)\n" \
+    MODULE_NAME ".get_device_settings(device, device_type, vnet_slot)\n" \
     "\n" \
     "Gets the settings in the device. vnet_slot defaults to " MODULE_NAME ".PlasmaIonVnetChannelMain\n" \
     "\n" \
     "Args:\n" \
     "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tdevice_type (EDeviceSettingsType): Optional: Overrides default device setings type. Defaults to '-1'\n\n" \
+    "\tvnet_slot (PlasmaIonVnetChannelMain): Optional: Defaults to PlasmaIonVnetChannelMain, Used only for PLASMA/ION Devices.\n\n" \
     "\n" \
     "Raises:\n" \
     "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
     "\n" \
     "Returns:\n" \
-    "\t:class:`" MODULE_NAME "."DEVICE_SETTINGS_OBJECT_NAME"`\n" \
+    "\t:class:`" MODULE_NAME ".""device_settings""`\n" \
     "\n" \
     "\t>>> d = ics.open_device()\n" \
     "\t>>> d.Name\n" \
@@ -418,42 +420,21 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "\t4\n" \
     "\t>>> s2.cyan\n" \
     "\t<ics.CyanSettings object at 0x02B113C8>\n" \
-    "\t>>> s2 = ics.get_device_settings(d, ics.PlasmaIonVnetChannelA)\n" \
+    "\t>>> s2 = ics.get_device_settings(d, -1, ics.PlasmaIonVnetChannelA)\n" \
     "\t>>> s2.DeviceSettingType\n" \
     "\t2\n" \
     "\t>>> s2.cyan.canfd1.FDMode\n" \
     "\t4\n"
-#else
-#define _DOC_GET_DEVICE_SETTINGS \
-    MODULE_NAME ".get_device_settings(device, device_type)\n" \
-    "\n" \
-    "Gets the settings in the device. device_type can override which setting object we deal with normally\n" \
-    "\n" \
-    "Args:\n" \
-    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
-    "\n" \
-    "Raises:\n" \
-    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
-    "\n" \
-    "Returns:\n" \
-    "\t:class:`" MODULE_NAME "." VCAN3_SETTINGS_OBJECT_NAME "` or :class:`" MODULE_NAME "." FIRE_SETTINGS_OBJECT_NAME "`.\n" \
-    "\n" \
-    "\t>>> device = ics.open_device()\n" \
-    "\t>>> settings = ics.get_device_settings(device)\n" \
-    "\t>>> type(settings)\n" \
-    "\t<class 'ics.FireSettings'>\n" \
-    "\t>>> \n" 
-#endif
 
-#if defined(USE_GENERIC_DEVICE_SETTINGS)
-    #define _DOC_SET_DEVICE_SETTINGS \
+
+#define _DOC_SET_DEVICE_SETTINGS \
     MODULE_NAME ".set_device_settings(device, settings, save_to_eeprom, vnet_slot)\n" \
     "\n" \
     "Sets the settings in the device. vnet_slot defaults to " MODULE_NAME ".PlasmaIonVnetChannelMain\n" \
     "\n" \
     "Args:\n" \
     "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
-    "\tsettings (:class:`" MODULE_NAME "."DEVICE_SETTINGS_OBJECT_NAME"`): :class:`" MODULE_NAME "."DEVICE_SETTINGS_OBJECT_NAME"`\n\n" \
+    "\tsettings (:class:`" MODULE_NAME ".""device_settings""`): :class:`" MODULE_NAME ".""device_settings""`\n\n" \
     "\n" \
     "Raises:\n" \
     "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
@@ -474,34 +455,6 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "\t>>> s.cyan.can_switch_mode = 2\n" \
     "\t>>> ics.set_device_settings(d, s, True, ics.PlasmaIonVnetChannelA)\n" \
     "\t>>> \n"
-#else // #if defined(USE_GENERIC_DEVICE_SETTINGS)
-#define _DOC_SET_DEVICE_SETTINGS \
-    MODULE_NAME ".set_device_settings(device, settings, device_type, save_to_eeprom)\n" \
-    "\n" \
-    "Sets the settings in the device.\n" \
-    "\n" \
-    "Args:\n" \
-    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
-    "\tsettings (:class:`" MODULE_NAME "." VCAN3_SETTINGS_OBJECT_NAME "`): :class:`" MODULE_NAME "." VCAN3_SETTINGS_OBJECT_NAME "`\n\n" \
-    "\tor:\n\n" \
-    "\tsettings (:class:`" MODULE_NAME "." FIRE_SETTINGS_OBJECT_NAME "`): :class:`" MODULE_NAME "." FIRE_SETTINGS_OBJECT_NAME "`\n\n" \
-    "\n" \
-    "Raises:\n" \
-    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
-    "\n" \
-    "Returns:\n" \
-    "\tNone.\n" \
-    "\n" \
-    "\t>>> device = ics.open_device()\n" \
-    "\t>>> settings = ics.get_device_settings(device)\n" \
-    "\t>>> type(settings)\n" \
-    "\t<class 'ics.FireSettings'>\n" \
-    "\t>>> settings.can1.Mode\n" \
-    "\t0\n" \
-    "\t>>> settings.can1.Mode = 3\n" \
-    "\t>>> ics.set_device_settings(device, settings)\n" \
-    "\t>>> \n"
-#endif
 
 //"Accepts a " MODULE_NAME "." NEO_DEVICE_OBJECT_NAME ", exception on error."
 #define _DOC_LOAD_DEFAULT_SETTINGS \
@@ -519,7 +472,7 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "\tNone.\n" \
     "\n" \
     "\t>>> device = ics.open_device()\n" \
-    "\t>>> settings = ics.load_default_settings(device)\n" \
+    "\t>>> ics.load_default_settings(device)\n" \
     "\t>>> \n"
 
 #define _DOC_CREATE_NEOVI_RADIO_MESSAGE \
@@ -910,7 +863,7 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
     "\n" \
     "Returns:\n" \
-    "\t(:class:`" MODULE_NAME "." API_FIRMWARE_INFO_OBJECT_NAME "`)\n" \
+    "\t(:class:`" MODULE_NAME "." "st_api_firmware_info" "`)\n" \
     "\n" \
     "\t>>> device = ics.open_device()\n" \
     "\t>>> info = ics.get_dll_firmware_info(device)\n" \
@@ -932,7 +885,7 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
     "\n" \
     "Returns:\n" \
-    "\t(:class:`" MODULE_NAME "." API_FIRMWARE_INFO_OBJECT_NAME "`)\n" \
+    "\t(:class:`" MODULE_NAME "." "st_api_firmware_info" "`)\n" \
     "\n" \
     "\t>>> device = ics.open_device()\n" \
     "\t>>> info = ics.get_hw_firmware_info(device)\n" \
@@ -999,7 +952,7 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "Args:\n" \
     "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
     "\n" \
-    "\tpMsg (:class:`" MODULE_NAME "." CM_ISO157652_TX_MESSAGE_OBJECT_NAME "`): :class:`" MODULE_NAME "." CM_ISO157652_TX_MESSAGE_OBJECT_NAME "`\n\n" \
+    "\tpMsg (:class:`" MODULE_NAME "." "st_cm_iso157652_tx_message" "`): :class:`" MODULE_NAME "." "st_cm_iso157652_tx_message" "`\n\n" \
     "\n" \
     "Raises:\n" \
     "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
@@ -1017,7 +970,7 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "Args:\n" \
     "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
     "\n" \
-    "\tprx_msg (:class:`" MODULE_NAME "." CM_ISO157652_RX_MESSAGE_OBJECT_NAME "`): :class:`" MODULE_NAME "." CM_ISO157652_RX_MESSAGE_OBJECT_NAME "`\n\n" \
+    "\tprx_msg (:class:`" MODULE_NAME "." "st_cm_iso157652_rx_message" "`): :class:`" MODULE_NAME "." "st_cm_iso157652_rx_message" "`\n\n" \
     "\n" \
     "Raises:\n" \
     "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
@@ -1196,7 +1149,7 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
     "\n" \
     "Returns:\n" \
-    "\t(:class:`" MODULE_NAME "." ICS_DEVICE_STATUS_OBJECT_NAME "`).\n" \
+    "\t(:class:`" MODULE_NAME "." "ics_device_status" "`).\n" \
     "\n" \
     "\t>>> import ics\n" \
     "\t>>> d = ics.open_device()\n" \
@@ -1273,6 +1226,126 @@ PyObject* meth_get_bus_voltage(PyObject* self, PyObject* args);
     "\t12000\n" \
     "\t>>> \n"
 
+#define _DOC_READ_JUPITER_FIRMWARE \
+    MODULE_NAME ".read_jupiter_firmware(device, size, [vnetChannel])\n" \
+    "\n" \
+    "Reads firmware binary from a RAD-Jupiter. If not sure, don't use this method\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\n" \
+    "\tsize (:class:`int`): :class:`int`: size of the bytes to read of the firmware binary.\n\n" \
+    "\n" \
+    "\tvnetChannel (:class:`int`): :class:`int`: Optional. Don't set, if unsure.\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone\n" \
+    "\n" \
+
+#define _DOC_WRITE_JUPITER_FIRMWARE \
+    MODULE_NAME ".write_jupiter_firmware(device, bytes, [vnetChannel])\n" \
+    "\n" \
+    "Writes firmware binary to a RAD-Jupiter. If not sure, don't use this method\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\n" \
+    "\tbytes (:class:`bytes`): :class:`bytes`: bytes of the firmware binary.\n\n" \
+    "\n" \
+    "\tvnetChannel (:class:`int`): :class:`int`: Optional. Don't set, if unsure.\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone\n" \
+    "\n" \
+
+#define _DOC_GET_DISK_DETAILS \
+    MODULE_NAME ".get_disk_details(device)\n" \
+    "\n" \
+    "Returns the device disk details.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\t(:class:`" MODULE_NAME "." "srad_gigalog_disk_details" "`).\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> details = ics.get_disk_details(d)\n" \
+    "\t>>> details.structure.options\n" \
+	"\t>>> \n"
+
+#define _DOC_DISK_FORMAT \
+    MODULE_NAME ".disk_format(device)\n" \
+    "\n" \
+    "Starts disk formatting on the device.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> details = ics.get_disk_details(d)\n" \
+    "\t>>> details. = ics.get_disk_details(d)\n" \
+    "\t>>> ics.disk_format(d, details)\n" \
+    "\t>>> \n"
+
+#define _DOC_DISK_FORMAT_CANCEL \
+    MODULE_NAME ".disk_format_cancel(device)\n" \
+    "\n" \
+    "Cancel in progress disk formatting on the device.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> ics.disk_format(d, details)\n" \
+    "\t>>> ics.disk_format_cancel(d)\n" \
+    "\t>>> \n"
+
+#define _DOC_DISK_FORMAT_PROGRESS \
+    MODULE_NAME ".get_disk_format_progress(device)\n" \
+    "\n" \
+    "Returns the device disk formatting progress.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\t(:class:`" MODULE_NAME "." "srad_gigalog_disk_format_progress" "`).\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> d = ics.disk_format(d, details)\n" \
+    "\t>>> progress = ics.get_disk_format_progress(d)\n" \
+    "\t>>> progress.sectorsRemaining\n" \
+	"\t>>> \n"
+
 static PyMethodDef IcsMethods[] = {
     _EZ_ICS_STRUCT_METHOD("find_devices", "icsneoFindNeoDevices", "FindNeoDevices", (PyCFunction)meth_find_devices, METH_VARARGS | METH_KEYWORDS, _DOC_FIND_DEVICES),
     _EZ_ICS_STRUCT_METHOD("open_device", "icsneoOpenNeoDevice", "OpenNeoDevice", (PyCFunction)meth_open_device, METH_VARARGS | METH_KEYWORDS, _DOC_OPEN_DEVICES),
@@ -1292,10 +1365,8 @@ static PyMethodDef IcsMethods[] = {
     _EZ_ICS_STRUCT_METHOD("flash_devices", "FlashDevice2", "FlashDevice2", meth_flash_devices, METH_VARARGS, "int _stdcall FlashDevice2()"),
 #endif
     _EZ_ICS_STRUCT_METHOD("set_reflash_callback", "icsneoSetReflashDisplayCallbacks", "SetReflashDisplayCallback", meth_set_reflash_callback, METH_VARARGS, _DOC_SET_REFLASH_CALLBACK),
-    _EZ_ICS_STRUCT_METHOD("get_device_settings", "icsneoGetFireSettings", "GetFireSettings", meth_get_device_settings, METH_VARARGS, _DOC_GET_DEVICE_SETTINGS),
-    _EZ_ICS_STRUCT_METHOD_MULTIPLE("get_device_settings", "icsneoGetVCAN3Settings", "GetVCAN3Settings", meth_get_device_settings, METH_VARARGS, _DOC_GET_DEVICE_SETTINGS),
-    _EZ_ICS_STRUCT_METHOD("set_device_settings", "icsneoSetFireSettings", "SetFireSettings", meth_set_device_settings, METH_VARARGS, _DOC_SET_DEVICE_SETTINGS),
-    _EZ_ICS_STRUCT_METHOD_MULTIPLE("set_device_settings", "icsneoSetVCAN3Settings", "SetVCAN3Settings", meth_set_device_settings, METH_VARARGS, _DOC_SET_DEVICE_SETTINGS),
+    _EZ_ICS_STRUCT_METHOD("get_device_settings", "icsneoGetDeviceSettings", "GetDeviceSettings", meth_get_device_settings, METH_VARARGS, _DOC_GET_DEVICE_SETTINGS),
+    _EZ_ICS_STRUCT_METHOD("set_device_settings", "icsneoSetDeviceSettings", "SetDeviceSettings", meth_set_device_settings, METH_VARARGS, _DOC_SET_DEVICE_SETTINGS),
     _EZ_ICS_STRUCT_METHOD("load_default_settings", "icsneoLoadDefaultSettings", "LoadDefaultSettings", meth_load_default_settings, METH_VARARGS, _DOC_LOAD_DEFAULT_SETTINGS),
     //_EZ_ICS_STRUCT_METHOD("spy_message_to_j1850", METH_spy_message_to_j1850, METH_VARARGS, "Accepts a " MODULE_NAME "." SPY_MESSAGE_OBJECT_NAME ", and returns a " MODULE_NAME "." SPY_MESSAGE_J1850_OBJECT_NAME ". Exception on error."),
     _EZ_ICS_STRUCT_METHOD("read_sdcard", "icsneoReadSDCard", "ReadSDCard", meth_read_sdcard, METH_VARARGS, "icsneoReadSDCard(), Accepts a " MODULE_NAME "." NEO_DEVICE_OBJECT_NAME " and sector index. Returns a bytearray of 512 bytes max. Exception on error."),
@@ -1324,7 +1395,7 @@ static PyMethodDef IcsMethods[] = {
     _EZ_ICS_STRUCT_METHOD("get_dll_firmware_info", "icsneoGetDLLFirmwareInfo", "GetDLLFirmwareInfo", meth_get_dll_firmware_info, METH_VARARGS, _DOC_GET_DLL_FIRMWARE_INFO),
     _EZ_ICS_STRUCT_METHOD("get_backup_power_enabled", "icsneoGetBackupPowerEnabled", "GetBackupPowerEnabled", meth_get_backup_power_enabled, METH_VARARGS, _DOC_GET_BACKUP_POWER_ENABLED),
     _EZ_ICS_STRUCT_METHOD("set_backup_power_enabled", "icsneoSetBackupPowerEnabled", "SetBackupPowerEnabled", meth_set_backup_power_enabled, METH_VARARGS, _DOC_SET_BACKUP_POWER_ENABLED),
-    _EZ_ICS_STRUCT_METHOD("get_backup_power_ready", "icsneoGetBackupPowerReady", "GetBackupPowerReady", meth_set_backup_power_ready, METH_VARARGS, _DOC_GET_BACKUP_POWER_READY),
+    _EZ_ICS_STRUCT_METHOD("get_backup_power_ready", "icsneoGetBackupPowerReady", "GetBackupPowerReady", meth_get_backup_power_ready, METH_VARARGS, _DOC_GET_BACKUP_POWER_READY),
 #ifdef _USE_INTERNAL_HEADER_
     _EZ_ICS_STRUCT_METHOD("load_readbin", "icsneoScriptLoadReadBin", "ScriptLoadReadBin", meth_load_readbin, METH_VARARGS, _DOC_LOAD_READBIN),
 #endif
@@ -1346,6 +1417,14 @@ static PyMethodDef IcsMethods[] = {
     _EZ_ICS_STRUCT_METHOD("enable_bus_voltage_monitor", "icsneoEnableBusVoltageMonitor", "EnableBusVoltageMonitor", meth_enable_bus_voltage_monitor, METH_VARARGS, _DOC_ENABLE_BUS_VOLTAGE_MONITOR),
     _EZ_ICS_STRUCT_METHOD("get_bus_voltage", "icsneoGetBusVoltage", "GetBusVoltage", meth_get_bus_voltage, METH_VARARGS, _DOC_GET_BUS_VOLTAGE),
 
+    _EZ_ICS_STRUCT_METHOD("read_jupiter_firmware", "icsneoReadJupiterFirmware", "ReadJupiterFirmware", meth_read_jupiter_firmware, METH_VARARGS, _DOC_READ_JUPITER_FIRMWARE),
+    _EZ_ICS_STRUCT_METHOD("write_jupiter_firmware", "icsneoWriteJupiterFirmware", "WriteJupiterFirmware", meth_write_jupiter_firmware, METH_VARARGS, _DOC_WRITE_JUPITER_FIRMWARE),
+
+    _EZ_ICS_STRUCT_METHOD("get_disk_details", "icsneoRequestDiskDetails", "RequestDiskDetails", meth_get_disk_details, METH_VARARGS, _DOC_GET_DISK_DETAILS),
+    _EZ_ICS_STRUCT_METHOD("disk_format", "icsneoRequestDiskFormat", "RequestDiskFormat", meth_disk_format, METH_VARARGS, _DOC_DISK_FORMAT),
+    _EZ_ICS_STRUCT_METHOD("disk_format_cancel", "icsneoRequestDiskFormatCancel", "RequestDiskFormatCancel", meth_disk_format_cancel, METH_VARARGS, _DOC_DISK_FORMAT_CANCEL),
+    _EZ_ICS_STRUCT_METHOD("get_disk_format_progress", "icsneoRequestDiskFormatProgress", "RequestDiskFormatProgress", meth_get_disk_format_progress, METH_VARARGS, _DOC_DISK_FORMAT_PROGRESS),
+
     {"override_library_name", (PyCFunction)meth_override_library_name, METH_VARARGS, _DOC_OVERRIDE_LIBRARY_NAME},
     {"get_library_path", (PyCFunction)meth_get_library_path, METH_NOARGS, ""},
 
