@@ -128,10 +128,16 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, NEODEVICE_RED2);
 	result += PyModule_AddIntMacro(module, NEODEVICE_ECU22);
 	result += PyModule_AddIntMacro(module, NEODEVICE_ETHER_BADGE);
-	result += PyModule_AddIntMacro(module, NEODEVICE_RADSTAR2_A2B);
+	result += PyModule_AddIntMacro(module, NEODEVICE_RAD_A2B);
 	result += PyModule_AddIntMacro(module, NEODEVICE_RADEPSILON);
 	result += PyModule_AddIntMacro(module, NEODEVICE_OBD2_SIM_DOIP);
 	result += PyModule_AddIntMacro(module, NEODEVICE_OBD2_DEV);
+	result += PyModule_AddIntMacro(module, NEODEVICE_NEW_DEVICE_54);
+	result += PyModule_AddIntMacro(module, NEODEVICE_NEW_DEVICE_55);
+	result += PyModule_AddIntMacro(module, NEODEVICE_NEW_DEVICE_56);
+	result += PyModule_AddIntMacro(module, NEODEVICE_NEW_DEVICE_57);
+	result += PyModule_AddIntMacro(module, NEODEVICE_NEW_DEVICE_58);
+	result += PyModule_AddIntMacro(module, NEODEVICE_NEW_DEVICE_59);
 	result += PyModule_AddIntMacro(module, NEODEVICE_RED);
 	result += PyModule_AddIntMacro(module, NEODEVICE_ECU);
 	result += PyModule_AddIntMacro(module, NEODEVICE_IEVB);
@@ -446,6 +452,8 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, OPETH_FUNC_MEDIACONVERTER);
 	result += PyModule_AddIntMacro(module, OPETH_FUNC_TAP_LOW_LATENCY);
 	result += PyModule_AddIntMacro(module, OPETH_FUNC_RAW_MEDIA_CONVERTER);
+	result += PyModule_AddIntMacro(module, OPETH_FUNC_RAW_MEDIA_CONVERTER2);
+	result += PyModule_AddIntMacro(module, OPETH_FUNC_RAW_MEDIA_CONVERTER2_LOW_LATENCY);
 	// end of enum -  };
 
 	result += PyModule_AddIntMacro(module, OP_ETH_GENERAL_SETTINGS_SIZE);
@@ -501,21 +509,30 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SDiskStructure_SIZE);
 	result += PyModule_AddIntMacro(module, SDiskDetails_SIZE);
 	result += PyModule_AddIntMacro(module, SDiskFormatProgress_SIZE);
+	// enum
+	result += PyModule_AddIntMacro(module, EXTENDED_RESPONSE_OK);
+	result += PyModule_AddIntMacro(module, EXTENDED_RESPONSE_INVALID_COMMAND);
+	result += PyModule_AddIntMacro(module, EXTENDED_RESPONSE_INVALID_STATE);
+	result += PyModule_AddIntMacro(module, EXTENDED_RESPONSE_OPERATION_FAILED);
+	// end of enum -  } ExtendedResponseCode;
+
 	result += PyModule_AddIntMacro(module, SExtSubCmdHdr_SIZE);
 	result += PyModule_AddIntMacro(module, SExtSubCmdComm_SIZE);
 	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_ENABLE);
-	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_RTSP_ENABLE);
-	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_AUTO_DETECT_ENABLE);
-	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_CONFIG_ENABLE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_RTSP_ENABLE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_AUTO_DET_RES_ENABLE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_CONFIG_ENABLE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_LOGGING_ENABLE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_TX0_ENABLE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_TX1_ENABLE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_TX2_ENABLE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_SETTINGS_FLAG_TX3_ENABLE);
 	// enum
-	result += PyModule_AddIntMacro(module, SERDESCAM_MODE_PASSTHROUGH);
-	result += PyModule_AddIntMacro(module, SERDESCAM_MODE_TAP);
-	result += PyModule_AddIntMacro(module, SERDESCAM_MODE_PLAYBACK);
-	// end of enum -  };
-
-	// enum
-	result += PyModule_AddIntMacro(module, SERDESCAM_CONFIG_MODE_EXTERNAL_OVER_TAP);
-	result += PyModule_AddIntMacro(module, SERDESCAM_CONFIG_MODE_LOCAL_SCRIPT);
+	result += PyModule_AddIntMacro(module, SERDESCAM_MODE_TAP_REPEATER);
+	result += PyModule_AddIntMacro(module, SERDESCAM_MODE_SPLITTER);
+	result += PyModule_AddIntMacro(module, SERDESCAM_MODE_LOG_ONLY);
+	result += PyModule_AddIntMacro(module, SERDESCAM_MODE_CUSTOM);
+	result += PyModule_AddIntMacro(module, SERDESCAM_MODE_COUNT);
 	// end of enum -  };
 
 	// enum
@@ -592,6 +609,30 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_RAW_30);
 	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_RAW_32);
 	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_RAW_36);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_RGGB_8);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_RGGB_10LE_PACKED);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_RGGB_12LE_PACKED);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_RGGB_16LE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_RGGB_16BE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_BAYER_RGGB_8);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_BAYER_RGGB_10LE_PACKED);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_BAYER_RGGB_12LE_PACKED);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_GBRG_8);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_GBRG_10LE_PACKED);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_GBRG_12LE_PACKED);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_GBRG_16LE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_GBRG_16BE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_BAYER_GBRG_8);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_BAYER_GBRG_10LE_PACKED);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_BAYER_GBRG_12LE_PACKED);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_GRBG_8);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_GRBG_10LE_PACKED);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_GRBG_12LE_PACKED);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_GRBG_16LE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_BAYER_GRBG_16BE);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_BAYER_GRBG_8);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_BAYER_GRBG_10LE_PACKED);
+	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_CSI2_BAYER_GRBG_12LE_PACKED);
 	result += PyModule_AddIntMacro(module, SERDESCAM_VIDEO_FORMAT_COUNT);
 	// end of enum -  };
 
@@ -600,6 +641,17 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SERDESPOC_SETTINGS_MODE_SUPPLY);
 	result += PyModule_AddIntMacro(module, SERDESPOC_SETTINGS_MODE_SERIALIZER);
 	result += PyModule_AddIntMacro(module, SERDESPOC_SETTINGS_SIZE);
+	// enum
+	result += PyModule_AddIntMacro(module, SERDESGEN_MOD_ID_NONE);
+	result += PyModule_AddIntMacro(module, SERDESGEN_MOD_ID_FPD3_2x2);
+	result += PyModule_AddIntMacro(module, SERDESGEN_MOD_ID_GMSL2_2x2);
+	result += PyModule_AddIntMacro(module, SERDESGEN_MOD_ID_GMSL1_4x4);
+	result += PyModule_AddIntMacro(module, SERDESGEN_MOD_ID_FPD3_TO_GMSL2_2x2);
+	result += PyModule_AddIntMacro(module, SERDESGEN_MOD_ID_UNKNOWN);
+	// end of enum -  };
+
+	result += PyModule_AddIntMacro(module, SERDESGEN_SETTINGS_FLAG_TX_PATGEN_ENABLE);
+	result += PyModule_AddIntMacro(module, SERDESGEN_SETTINGS_SIZE);
 	result += PyModule_AddIntMacro(module, RADMOONDUO_CONVERTER_SETTINGS_SIZE);
 	result += PyModule_AddIntMacro(module, RAD_REPORTING_SETTINGS_FLAG_TEMP_ENABLE);
 	result += PyModule_AddIntMacro(module, RAD_REPORTING_SETTINGS_FLAG_MIC2_GPS_ENABLE);
@@ -610,7 +662,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, RAD_REPORTING_SETTINGS_FLAG_MISC1_PWMIN);
 	result += PyModule_AddIntMacro(module, RAD_REPORTING_SETTINGS_FLAG_MISC2_PWMIN);
 	result += PyModule_AddIntMacro(module, RAD_REPORTING_SETTINGS_FLAG_AIN1);
-	result += PyModule_AddIntMacro(module, RAD_REPORTING_SETTINGS_FLAG_AIN2);
+	result += PyModule_AddIntMacro(module, RAD_REPORTING_SETTINGS_FLAG_SERDES_ENABLE);
 	result += PyModule_AddIntMacro(module, RAD_REPORTING_SETTINGS_SIZE);
 	// enum
 	result += PyModule_AddIntMacro(module, REPORT_ON_PERIODIC);
@@ -646,6 +698,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SRADGalaxySettings_SIZE);
 	result += PyModule_AddIntMacro(module, SRADStar2Settings_SIZE);
 	result += PyModule_AddIntMacro(module, SRADSuperMoonSettings_SIZE);
+	result += PyModule_AddIntMacro(module, SRADA2BSettings_SIZE);
 	result += PyModule_AddIntMacro(module, SRADMoon2Settings_SIZE);
 	result += PyModule_AddIntMacro(module, SRADGigalogSettings_SIZE);
 	result += PyModule_AddIntMacro(module, SRADGigastarSettings_SIZE);
@@ -726,6 +779,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, DeviceFire3SettingsType);
 	result += PyModule_AddIntMacro(module, DeviceRadMoonDuoSettingsType);
 	result += PyModule_AddIntMacro(module, DeviceEtherBadgeSettingsType);
+	result += PyModule_AddIntMacro(module, DeviceRADA2BSettingsType);
 	result += PyModule_AddIntMacro(module, DeviceSettingsTypeMax);
 	result += PyModule_AddIntMacro(module, DeviceSettingsNone);
 	// end of enum -  } EDeviceSettingsType;
@@ -753,6 +807,23 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, PHY_REG_PKT_VERSION);
 	result += PyModule_AddIntMacro(module, MAX_PHY_SETTINGS_STRUCT);
 	result += PyModule_AddIntMacro(module, MAX_NUMBYTES_PHYSETTINGS);
+	// enum
+	result += PyModule_AddIntMacro(module, PHYREG_SUCCESS);
+	result += PyModule_AddIntMacro(module, PHYREG_FAILURE);
+	result += PyModule_AddIntMacro(module, PHYREG_INVALID_MDIO_BUS_INDEX);
+	result += PyModule_AddIntMacro(module, PHYREG_INVALID_PHY_ADDR);
+	result += PyModule_AddIntMacro(module, PHYREG_RESERVED0);
+	result += PyModule_AddIntMacro(module, PHYREG_RESERVED1);
+	result += PyModule_AddIntMacro(module, PHYREG_RESERVED2);
+	result += PyModule_AddIntMacro(module, PHYREG_RESERVED3);
+	// end of enum -  } PhyRegPktStatus_t;
+
+	// enum
+	result += PyModule_AddIntMacro(module, PHYREG_READ);
+	result += PyModule_AddIntMacro(module, PHYREG_WRITE);
+	result += PyModule_AddIntMacro(module, PHYREG_BOTH);
+	// end of enum -  } PhyRegPktRw_t;
+
 	// enum
 	// end of enum -  	}
 
